# PyMEOS

This repository contains 3 Projects:
- [PyMEOS CFFI](./pymeos_cffi):  
  Wrapper of the MEOS C Library built using CFFI, not meant to be used directly.
- [PyMEOS](./pymeos)  
  PyMEOS Library that exposes the set of classes that should be used by the developer. Uses PyMEOS CFFI under the hood.
- [PyMEOS Examples](./pymeos_examples)  
  Set of example programs using PyMEOS.
